Skip to contents

Returns a player's full statistical profile with ranks and values for 130+ stats in a single call. Much more efficient than pulling individual stats with pga_stats().

Usage

pga_player_stats(player_id)

Arguments

player_id

Character. Player ID.

Value

A tibble with one row per stat including stat_id, title, rank, value, category, and supporting stats.

Examples

if (FALSE) { # \dontrun{
pga_player_stats("52955")
} # }