Returns the full tournament schedule for a season including dates, status, purse, course, champion, and FedExCup points.
Usage
pga_schedule(year = as.integer(format(Sys.Date(), "%Y")), tour = "R")Returns the full tournament schedule for a season including dates, status, purse, course, champion, and FedExCup points.
pga_schedule(year = as.integer(format(Sys.Date(), "%Y")), tour = "R")