Returns a list of speed-round videos for a given tour. Useful as a content discovery surface; returned as a nested list because the entry shapes are heterogeneous.
Returns a list of speed-round videos for a given tour. Useful as a content discovery surface; returned as a nested list because the entry shapes are heterogeneous.