Returns tournament details including name, location, courses, weather, status, and format.
Examples
if (FALSE) { # \dontrun{
pga_tournaments("R2026475")
pga_tournaments(c("R2026475", "R2026003"))
} # }
Returns tournament details including name, location, courses, weather, status, and format.
if (FALSE) { # \dontrun{
pga_tournaments("R2026475")
pga_tournaments(c("R2026475", "R2026003"))
} # }